from .models import (
    test_contract,
    test_contract_line,
    test_crm_lead_line,
    test_crm_lead,
    test_ir_server_action,
    test_res_partner,
)
from .listeners import (
    test_crm_lead_listener,
)
from .wizards import test_create_lead_from_partner, test_crm_lead_add_multimedia_line
from . import helper_service
